# Django settings for sommitrealweird project.

# Rather than editing these here, add them to the localsettings.py file which
# will be included at the end of the run

import os

topdir = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))

ADMINS = (
    ('Brett Parker', 'iDunno@sommitrealweird.co.uk'),
)

ALLOWED_HOSTS = [
    "www.sommitrealweird.co.uk",
    "www.sommitrealweird.co.uk.",
    "10.0.3.191",
]

MANAGERS = ADMINS

DATABASES = {
    'default': {
            'ENGINE': 'django.db.backends.sqlite3',
            'NAME': os.path.join(topdir, 'sommitrealweird.db')
    }
}

TIME_ZONE = 'Europe/London'

LANGUAGE_CODE = 'en-gb'

SITE_ID = 1

TEST_RUNNER = 'django.test.runner.DiscoverRunner'

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

MEDIA_ROOT = os.path.join(topdir, 'media') + os.sep
MEDIA_URL = '/media/'

STATIC_ROOT = '/usr/lib/python3/dist-packages/django/contrib/admin/static/'
STATIC_URL = '/static/'

import random
import string
key_chars = "%s%s%s" % (string.ascii_letters, string.digits, '+-()_#~')
SECRET_KEY = [random.choice(key_chars) for a in range(0,50)]

CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.filebased.FileBasedCache',
        'LOCATION': '%s/tmp' %(topdir),
    }
}

MIDDLEWARE = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.admindocs.middleware.XViewMiddleware',
)

ROOT_URLCONF = 'urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(topdir, 'templates'),],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'django.template.context_processors.debug',
                'django.template.context_processors.i18n',
                'django.template.context_processors.media',
                'bpcms.context_processors.content_menu',
                'bpcms.context_processors.content_submenu',
                'bpcms.context_processors.content_breadcrumb',
                'blog.context_processors.content_breadcrumb',
                'blog.context_processors.blog_feed',
                'photo.context_processors.content_breadcrumb',
            ],
            'debug': True,
        },
    },
]

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.admin',
    'django.contrib.messages',
    'bpcms',
    'generic',
    'blog',
    'photo',
)


APPEND_SLASH=False

RESTRUCTUREDTEXT_FILTER_SETTINGS = {
    'initial_header_level': 2,
    'doctitle_xform': False,
}

BPCMS_ROOT = '/'
BPCMS_DISALLOWED_ROOT_DOC_NAMES = (
    'admin',
    'blog',
    'photos',
)

BLOG_ROOT = '/blog/'
BLOG_TITLE = u'The World of SommitRealWeird.'
BLOG_FEED_ROOT = '/feeds/blog/'

try:
    from localsettings import *
except:
    pass

